# Step 1: Understand Your Strategy
### On this page
  * [Define “Modern”](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy#define-%E2%80%9Cmodern%E2%80%9D)
  * [Identify Stakeholders](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy#identify-stakeholders)
  * [Align on KPIs and OKRs](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy#align-on-kpis-and-okrs)
  * [Set the Timeline](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy#set-the-timeline)
  * [Example](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy#example)


Get clear on what modernization means for your organization to guide decisions and priorities during transformation initiatives.
Before you start your transformation, work with business stakeholders to get clear on what modernization means for your organization. This shared understanding will guide decisions, priorities, and measurements throughout the initiative. The following sections outline the key steps involved in this process.
